/* taglib_config.h. Generated by cmake from taglib_config.h.cmake */

#ifndef TAGLIB_TAGLIB_CONFIG_H
#define TAGLIB_TAGLIB_CONFIG_H

/* These values are no longer used. This file is present only for compatibility reasons. */

#define   TAGLIB_WITH_ASF 1
#define   TAGLIB_WITH_MP4 1

#endif
